@@ -55,10 +55,16 @@ class HTMLMacroExpansion(HTMLBugPathEvent):
 HTMLMacroExpansions = List[HTMLMacroExpansion]
 
 
+class Checker(TypedDict):
+    name: str
+    url: Optional[str]
+
+
 class HTMLReport(TypedDict):
     fileId: str
     reportHash: Optional[str]
-    checkerName: str
+    checker: Checker
+    analyzerName: Optional[str]
     line: int
     column: int
     message: str
@@ -103,7 +109,6 @@ class HtmlBuilder:
         self._checker_labels = checker_labels
         self.layout_dir = layout_dir
         self.generated_html_reports: Dict[str, HTMLReports] = {}
-        self.html_reports: HTMLReports = []
         self.files: FileSources = {}
 
         css_dir = os.path.join(self.layout_dir, 'css')
@@ -151,13 +156,13 @@ class HtmlBuilder:
         return self._checker_labels.severity(checker_name) \
             if self._checker_labels else 'UNSPECIFIED'
 
-    def _add_source_file(self, file: File):
+    def _add_source_file(self, file: File) -> FileSource:
         """
         Updates file source data by file id if the given file hasn't been
         processed.
         """
         if file.id in self.files:
-            return
+            return self.files[file.id]
 
         try:
             file_content = file.content
@@ -167,17 +172,36 @@ class HtmlBuilder:
         self.files[file.id] = {
             'filePath': file.path, 'content': file_content}
 
-    def _add_html_reports(
+        return self.files[file.id]
+
+    def _get_doc_url(self, report: Report) -> Optional[str]:
+        """ Get documentation url for the given report if exists. """
+        if self._checker_labels:
+            doc_urls = self._checker_labels.label_of_checker(
+                report.checker_name, 'doc_url', report.analyzer_name)
+            return doc_urls[0] if doc_urls else None
+
+        return None
+
+    def _get_html_reports(
         self,
         reports: List[Report]
-    ):
+    ) -> Tuple[HTMLReports, FileSources]:
+        """ Get HTML reports from the given reports.
+
+        Returns a list of html reports and references to file sources.
+        """
+        html_reports: HTMLReports = []
+        files: FileSources = {}
+
         def to_bug_path_events(
             events: List[BugPathEvent]
         ) -> HTMLBugPathEvents:
             """ Converts the given events to html compatible format. """
             html_events: HTMLBugPathEvents = []
             for event in events:
-                self._add_source_file(event.file)
+                files[event.file.id] = self._add_source_file(event.file)
+
                 html_events.append({
                     'message': event.message,
                     'fileId': event.file.id,
@@ -192,7 +216,9 @@ class HtmlBuilder:
             """ Converts the given events to html compatible format. """
             html_macro_expansions: HTMLMacroExpansions = []
             for macro_expansion in macro_expansions:
-                self._add_source_file(macro_expansion.file)
+                files[macro_expansion.file.id] = self._add_source_file(
+                    macro_expansion.file)
+
                 html_macro_expansions.append({
                     'message': macro_expansion.message,
                     'name': macro_expansion.name,
@@ -203,12 +229,16 @@ class HtmlBuilder:
             return html_macro_expansions
 
         for report in reports:
-            self._add_source_file(report.file)
+            files[report.file.id] = self._add_source_file(report.file)
 
-            self.html_reports.append({
+            html_reports.append({
                 'fileId': report.file.id,
                 'reportHash': report.report_hash,
-                'checkerName': report.checker_name,
+                'checker': {
+                    'name': report.checker_name,
+                    'url': self._get_doc_url(report)
+                },
+                'analyzerName': report.analyzer_name,
                 'line': report.line,
                 'column': report.column,
                 'message': report.message,
@@ -219,6 +249,8 @@ class HtmlBuilder:
                 'severity': self.get_severity(report.checker_name)
             })
 
+        return html_reports, files
+
     def create(
         self,
         output_file_path: str,
@@ -233,15 +265,15 @@ class HtmlBuilder:
         if changed_files:
             return None, changed_files
 
-        self._add_html_reports(reports)
+        html_reports, files = self._get_html_reports(reports)
 
-        self.generated_html_reports[output_file_path] = self.html_reports
+        self.generated_html_reports[output_file_path] = html_reports
 
         substitute_data = self._tag_contents
         substitute_data.update({
             'report_data': json.dumps({
-                'files': self.files,
-                'reports': self.html_reports
+                'files': files,
+                'reports': html_reports
             })
         })
 
@@ -251,7 +283,7 @@ class HtmlBuilder:
                   encoding='utf-8', errors='replace') as f:
             f.write(content)
 
-        return self.html_reports, changed_files
+        return html_reports, changed_files
 
     def create_index_html(self, output_dir: str):
         """
@@ -309,6 +341,14 @@ class HtmlBuilder:
                 rs = review_status.lower().replace(' ', '-')
                 file_path = self.files[report['fileId']]['filePath']
 
+                checker = report['checker']
+                doc_url = checker.get('url')
+                if doc_url:
+                    checker_name_col_content = f'<a href="{doc_url}" '\
+                        f'target="_blank">{checker["name"]}</a>'
+                else:
+                    checker_name_col_content = checker["name"]
+
                 table_reports.write(f'''
                   <tr>
                     <td>{i + 1}</td>
@@ -321,7 +361,7 @@ class HtmlBuilder:
                       <i class="severity-{severity}"
                          title="{severity}"></i>
                     </td>
-                    <td>{report['checkerName']}</td>
+                    <td>{checker_name_col_content}</td>
                     <td>{message}</td>
                     <td class="bug-path-length">{bug_path_length}</td>
                     <td class="review-status review-status-{rs}">
@@ -362,7 +402,7 @@ class HtmlBuilder:
         checker_statistics: Dict[str, int] = defaultdict(int)
         for html_file in self.generated_html_reports:
             for report in self.generated_html_reports[html_file]:
-                checker = report['checkerName']
+                checker = report['checker']['name']
                 checker_statistics[checker] += 1
 
         checker_rows: List[List[str]] = []
@@ -442,18 +482,18 @@ def convert(
     Returns the skipped analyzer result files because of source
     file content change.
     """
+    if not reports:
+        LOG.info(f'No report data in {file_path} file.')
+        return set()
+
     html_filename = f"{os.path.basename(file_path)}.html"
     html_output_path = os.path.join(output_dir_path, html_filename)
-    html_reports, changed_files = html_builder.create(
+    _, changed_files = html_builder.create(
         html_output_path, reports)
 
     if changed_files:
         return changed_files
 
-    if not html_reports:
-        LOG.info(f'No report data in {file_path} file.')
-        return changed_files
-
     LOG.info(f"Html file was generated: {html_output_path}")
     return changed_files
 
